@@ -29,7 +29,6 @@ signer = leselys.core.signer
 # Get unreaded counters
 @app.route('/api/counters')
 @login_required
-@cached(10)
 def get_counters():
     feeds = reader.get_feeds()
     res = []
@@ -52,11 +51,15 @@ def remove(feed_id):
 
 
 # Return list of entries for given feed_id
-@app.route('/api/get/<feed_id>', defaults={'order_type': 'normal'})
-@app.route('/api/get/<feed_id>/<order_type>')
+# Or all if feed_id not specified
+@app.route('/api/get', defaults={'feed_id': False})
+@app.route('/api/get/<feed_id>')
 @login_required
-def get(feed_id, order_type):
-    return jsonify(content=reader.get(feed_id, order_type))
+def get(feed_id):
+    order_type = request.args.get('order_type', 'user')
+    start = request.args.get('start', 0)
+    end = request.args.get('end', 100)
+    return jsonify(content=reader.get(feed_id, order_type, start, end))
 
 
 # Set story as readed
@@ -177,3 +180,13 @@ def change_setting():
     value = request.form['value']
     storage.set_setting(setting, value)
     return jsonify(success=True, output="%s setting have been set at %s" % (setting, value))
+
+# Set feedsettings
+@app.route('/api/feedsettings', methods=['POST'])
+@login_required
+def change__feed_setting():
+    feed_id = request.form['feed_id']
+    key = request.form['key']
+    value = request.form['value']
+    storage.set_feed_setting(feed_id, key, value)
+    return jsonify(success=True, output="%s setting have been set at %s" % (key, value))
