@@ -1,9 +1,11 @@
 # -*- coding: utf-8 -*-
 import sys
+import pymongo
 
 from pymongo import MongoClient
 from bson.objectid import ObjectId
 from _storage import Storage
+from leselys.helpers import get_datetime
 
 
 class Mongodb(Storage):
@@ -42,17 +44,27 @@ class Mongodb(Storage):
         return str(self.db.users.save({'username': username,
                                        'password': password}))
 
+    def set_feed_setting(self, feed_id, setting_type, value):
+        setting = self.db.feedsettings.find_one({'feed_id': feed_id, 'setting_type': setting_type})
+        if setting:
+            self.db.feedsettings.remove(setting['_id'])
+        self.db.feedsettings.save({'feed_id':feed_id, 'setting_type': setting_type, 'value': value})
+
+    def get_feed_setting(self, feed_id, setting_type):
+        setting = self.db.feedsettings.find_one({'feed_id': feed_id, 'setting_type': setting_type})
+        if setting:
+            setting['_id'] = str(setting['_id'])
+        return setting
+
     def set_setting(self, key, value):
+        self.db.settings.remove({key: {'$exists':True}})
         return str(self.db.settings.save({key: value}))
 
     def get_setting(self, key):
-        if not self.db.settings.find_one():
-            return False
-        if not self.db.settings.find_one().get(key, False):
-            return False
-        else:
-            setting = self.db.settings.find_one()[key]
-            return setting
+        setting = self.db.settings.find_one({key: {'$exists': True}})
+        if setting:
+            return setting[key]
+        return False
 
     def get_settings(self):
         settings = {}
@@ -69,6 +81,8 @@ class Mongodb(Storage):
         self.db.feeds.remove(ObjectId(_id))
         for entry in self.db.stories.find({'feed_id': _id}):
             self.db.stories.remove(entry['_id'])
+        for setting in self.db.feedsettings.find({'feed_id': _id}):
+            self.db.feedsettings.remove(setting['_id'])
 
     def get_feed_by_id(self, _id):
         feed = self.db.feeds.find_one(ObjectId(_id))
@@ -99,6 +113,13 @@ class Mongodb(Storage):
             res.append(feed)
         return res
 
+    def all_stories(self):
+        res = []
+        for story in self.db.stories.find():
+            story['_id'] = str(story['_id'])
+            res.append(story)
+        return res
+
     def add_story(self, content):
         return str(self.db.stories.save(content))
 
