@@ -47,6 +47,8 @@ class Retriever(threading.Thread):
         self.do_retention = do_retention
         if feed_from_db:
             self.title = feed_from_db['title']
+        else:
+            self.title = feed['feed']['title']
 
     def run(self):
         # This feed comes from database
@@ -220,39 +222,91 @@ class Reader(object):
         storage.remove_feed(feed_id)
         return {"success": True, "output": "Feed removed"}
 
-    def get(self, feed_id, order_type='normal'):
+    def get(self, feed_id=False, order_type="user", start=0, end=100):
+        if not feed_id:
+            if order_type == "user" or order_type not in ['unreaded', 'published']:
+                order_type = storage.get_setting('all_items_ordering')
+                if not order_type:
+                    storage.set_setting('all_items_ordering', 'unreaded')
+                    order_type = storage.get_setting('all_items_ordering')
+        else:
+            if order_type == "user" or order_type not in ['unreaded', 'published']:
+                setting_order_type = storage.get_feed_setting(feed_id, 'ordering')
+                if not setting_order_type:
+                    storage.set_feed_setting(feed_id, 'ordering', 'unreaded')
+                    order_type = 'unreaded'
+                else:
+                    order_type = setting_order_type['value']
+
+        if not feed_id:
+            stories = storage.all_stories()
+        else:
+            stories = storage.get_stories(feed_id)
+
+
         res = []
-        for entry in storage.get_stories(feed_id):
-            res.append({
-                "title": entry['title'],
-                "_id": entry['_id'],
-                "read": entry['read'],
-                'last_update': entry['last_update']})
+        entries = []
+        if order_type == 'unreaded':
+            for entry in stories:
+                story = {
+                    "title": entry['title'],
+                    "_id": entry['_id'],
+                    "read": entry['read'],
+                    'last_update': entry['last_update']}
+                if not feed_id:
+                    story['feed_id'] = entry['feed_id']
 
-        # Must implement different order_type
+                res.append(story)
 
-        # Readed
-        readed = []
-        for entry in res:
-            if entry['read']:
-                readed.append(entry)
-        readed.sort(key=lambda r: get_datetime(r['last_update']), reverse=True)
-        # Unread
-        unreaded = []
-        for entry in res:
-            if not entry['read']:
-                unreaded.append(entry)
-        unreaded.sort(key=lambda r: get_datetime(r['last_update']),
-                      reverse=True)
-        return unreaded + readed
+            # Readed
+            readed = []
+            for entry in res:
+                if entry['read']:
+                    readed.append(entry)
+            readed.sort(key=lambda r: get_datetime(r['last_update']), reverse=True)
+            # Unread
+            unreaded = []
+            for entry in res:
+                if not entry['read']:
+                    unreaded.append(entry)
+            unreaded.sort(key=lambda r: get_datetime(r['last_update']),
+                          reverse=True)
+
+            entries = unreaded + readed
+
+        elif order_type == 'published':
+            for entry in stories:
+                story = {
+                    "title": entry['title'],
+                    "_id": entry['_id'],
+                    "read": entry['read'],
+                    'last_update': entry['published']}
+                if not feed_id:
+                    story['feed_id'] = entry['feed_id']
+
+                res.append(story)
+
+            res.sort(key=lambda r: get_datetime(r['last_update']),
+                          reverse=True)
+            entries = res
+
+        return {'entries': entries, 'ordering': order_type}
 
     def get_feeds(self):
         feeds = []
         for feed in storage.get_feeds():
+            ordering = storage.get_feed_setting(feed['_id'], 'ordering')
+            if not ordering:
+                storage.set_feed_setting(feed['_id'], 'ordering', 'unreaded')
+                ordering = storage.get_feed_setting(feed['_id'], 'ordering')
+
+            ordering = ordering['value']
+
             feeds.append({'title': feed['title'],
                           'id': feed['_id'],
                           'url': feed['url'],
-                          'counter': self.get_unread(feed['_id'])
+                          'counter': self.get_unread(feed['_id']),
+                          'ordering': ordering
                           })
         return feeds
 
@@ -308,3 +362,4 @@ class Reader(object):
         story['read'] = False
         storage.update_story(story['_id'], copy.copy(story))
         return {'success': True, 'content': story}
+
